/*
*  Rubrica
*  file: addressbook.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gnome.h>

#include "rubrica.h"
#include "addressbook.h"
#include "interface.h"
#include "dialoghi.h"
#include "file.h"


#define RUBRICA_TEST(number)  if ((number) < 0) \
                                 g_warning("richiesta una rubrica non esistente");

GList *book = NULL;          /* list of addressbooks */
gint pages = 0;              /* pages count the number of all notebook pages,
				each page is an addressbook.  */

/* return the number of addressbook */
inline gint 
rubrica_get_pages(void)
{
  return pages;
}

/* add an addressbook */
inline void 
rubrica_pages_inc(void)
{
  pages++;
}

/* delete an addressbook */
inline void 
rubrica_pages_dec(void)
{
  pages--;
}

/* set addressbook number to n */
inline void 
rubrica_page_set(gint n)
{
  pages = n;
}

/* init addressbook */
void rubrica_init_addressbook(void)
{
  /*     the first addressbook of addressbooks.    
   */
  AddressBook *ab;

  ab = g_malloc(sizeof(AddressBook));

  ab->rubrica = NULL;
  ab->modified = FALSE;
  ab->empty = TRUE;
  ab->new = TRUE;

  ab->name = NULL;
  ab->path = NULL;

  ab->notebook = NULL;
  ab->child = NULL;
  ab->clist = NULL;
  ab->label = NULL;

  ab->item_in_list = 0;
  ab->nb_page = 0;
    
  book = g_list_append(book, ab);  
}

/* insert a new addressbook in book */
void rubrica_addressbook_append(AddressBook *ab)
{
  book = g_list_append(book, ab);
}

/* return the addressbook in position number "number" */
AddressBook *rubrica_get_addressbook(gint number)
{
  RUBRICA_TEST(number);
  
  return (AddressBook *) g_list_nth_data(book, number);
}


/* init an addressbook item */
void rubrica_init_addressbook_item(AddressBook *ab)
{
  ab->rubrica = NULL;
  ab->modified = FALSE;
  ab->empty = TRUE;
  ab->new = TRUE;

  ab->name = NULL;
  ab->path = NULL;

  ab->item_in_list = 0;
}

/*
  Make a new notebook page that contains a cards clist and append it at 
  notebook end. Allocate memory for new addressbook item and fill 
  infos field with the "notebooks" value.

  return the number of new page
*/
gint
rubrica_do_new_addressbook(gpointer data, gchar *filename)
{
  GtkWidget *app = (GtkWidget *) data;  /* ptr to main application */

  AddressBook *ab;                      /* the new addressbook item */
  GtkWidget *notebook,      /* */     
    *child,                 /* notebook child, this will contain cards clist */
    *label,                 /* notebook tab label */
    *clist;                 /* the cards clist */
  gint page;                /* # of new notebook page */
  gchar *path, *fname = NULL;

  if (filename)
    {
      path = g_dirname(filename);
      fname = g_basename(filename);
    }
  else
//    path = g_get_current_dir();
    path = NULL;

  /* do new addressbook, init and insert it in addressbooks 
     list. It will be related to new notebook page  */
  ab = (AddressBook *) g_malloc(sizeof(AddressBook));
  rubrica_init_addressbook_item(ab); 
  rubrica_addressbook_append(ab);

  notebook = gtk_object_get_data(GTK_OBJECT(app), "cards_notebook");

  /* save current page number */
  page = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
  rubrica_set_current_page(page);

  /* make notebook page's child */
  child = rubrica_interface_insert_new_view(&clist);

  /* tab label */
  if (!fname)
    fname = _("no name");
  label = gtk_label_new (fname);  

  /* NOTA:
     l'etichetta da inserire nel notebook, NON DEVE ESSERE MOSTRATA
     DON'T SHOW the label that will be inserted in notebook  
  */

  /* append new notebook page */
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child, label);    

  /* get the number of this page */
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), child);  

  /* store infos about this page */
  addressbook_store_info(NULL, FALSE, TRUE, page);
  addressbook_store_widget_info(notebook, child, clist, label, page);
  addressbook_store_path_and_name(path, fname, page);

  /* switch to page number "page" */
  gtk_notebook_set_page(GTK_NOTEBOOK(notebook), page); 

  /* init views */
  rubrica_init_addressbook_view();

  /* increase pages counter */
  rubrica_pages_inc();
 
  /* return the number of new page */
  return (gint) page;
}


/*
  copy the content of addressbook number page to global variables.
*/
void rubrica_apply_addressbook(gint page)
{
  AddressBook *ab;
  gint item;

  /* book is a list of lists and contains all addressbooks opened. 
     Each notebook page is one addressbook. Data contained in list item
     contains ptr to real address, plus some infos about the addressbook
  */

  /* get data from position "page" */
  ab = g_list_nth_data(book, page);

  /* items in addressbook */
  item = g_list_length(ab->rubrica); 
  if (item != ab->item_in_list)
    ab->item_in_list = item;

  /* set global variables to ab content */
  rubrica_set_rubrica(ab->rubrica);
  
  if (ab->rubrica)
    rubrica_set_new(FALSE);
  else
    rubrica_set_new(TRUE);
  
  rubrica_modificata(ab->modified);
  rubrica_set_empty(ab->empty);
  rubrica_file_set_names(ab->path, ab->name);
  rubrica_vista_set_schede(ab->clist);
  rubrica_vista_set_indirizzi(ab->item_in_list);    
  
  if (rubrica_file_is_start())
    rubrica_file_set_start(FALSE);
}


/*  return path and filename of addressbook number page
*/
void addressbook_get_path_and_name(gchar **path, gchar **name, gint page)
{ 
  AddressBook *data;

  RUBRICA_TEST(page);

  data = (AddressBook *) g_list_nth_data(book, page);

  if (!data)
    {
      *path = NULL;
      *name = NULL;
	
      return;
    }

  *path = g_strdup(data->path);
  *name = g_strdup(data->name);
}

/* 
   save path and name in addressbook number page
*/
void addressbook_store_path_and_name(gchar *path, gchar *name, gint page)
{
  AddressBook *data;

  RUBRICA_TEST(page);

  /* get data of the nth item of book (an AddressBook) and replace name and path */
  data = (AddressBook*) g_list_nth_data(book, page);

  if (data->name)
    g_free(data->name);
  data->name = g_strdup(name);

  if (data->path)
    g_free(data->path);
  data->path = g_strdup(path);

  /* show new filename in notebook tab */
  gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(data->notebook), 
				  data->child, data->name);
}


void addressbook_store_info(GList *rub, gboolean mod, gboolean emp, gint pos)
{
  GList *ab;
  AddressBook *data;
  
  ab = g_list_nth(book, pos);
  data = (AddressBook *) g_list_nth_data(book, pos);

  g_return_if_fail(ab != NULL);

  if (!data)
    data = g_malloc(sizeof(AddressBook));

  data->rubrica = rub;
  data->modified = mod;
  data->empty = emp;
  data->item_in_list = g_list_length(rub); 
  
  ab->data = data;
}

void addressbook_store_widget_info(GtkWidget *notebook, GtkWidget * child, 
				   GtkWidget *clist, GtkWidget *label, 
				   gint page)
{
  GList *ab;
  AddressBook *data;
  
  ab = g_list_nth(book, page);
  data = (AddressBook *) g_list_nth_data(book, page);  
  
  g_return_if_fail(ab != NULL);
  
  if (!data)
    {
      data = g_malloc(sizeof(AddressBook));
      rubrica_init_addressbook_item(data);
    }
  
  data->nb_page = page;
  data->notebook = notebook;
  data->child = child;
  data->clist = clist;
  data->label = label;  

  ab->data = data;
  
}

void addressbook_set_rubrica(GList *rub, gboolean new, gint page)
{
  GList *ab;
  AddressBook *data;
  
  ab = g_list_nth(book, page);
  data = (AddressBook *) g_list_nth_data(book, page);  
  
  g_return_if_fail(ab != NULL);
  
  if (!data)    
      data = g_malloc(sizeof(AddressBook));
  
  data->rubrica = rub;
  data->new = new;

  ab->data = data;  
}

void rubrica_close_addressbook(gpointer notebook)
{  
  AddressBook *ab;
  gint page, scelta;
  gchar *mes;
  
//  page = rubrica_get_current_page();
  page = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
  ab = rubrica_get_addressbook(page);
  
  if (ab->modified)
    {
      mes = g_strdup(_("Warning. Address book was changed.\nChanges not saved, will be lose.\nContinue?")); 
      
      scelta = confirm_file_close(mes);
      g_free(mes);
      
      switch(scelta)
	{
	case 0:
	  rubrica_real_close(ab, notebook, page);
	  break;
	  
	case 1:
	default:
	  break;
	}  
    }
  rubrica_real_close(ab, notebook, page);
}

void rubrica_real_close(AddressBook *ab, gpointer notebook, gint page)
{
  /* per chiudere un file, devo liberare la memoria che occupa
     devo estrarre da book (la lista degli addressbook) l'elemento che 
     contiene il ptr alla vera rubrica e liberare la memoria occupata.
     Quindi liberare la memoria occupata dal nodo
  */
  GList *nodo;
  GtkWidget *cards;
  gint pages;

  /* get the number of pages in notebook */
  pages = rubrica_get_pages();
  
  /* page is the number of current page */

  /*     Free memory
  */
  rubrica_svuota_memoria(ab->rubrica);
  if (ab->name)
    g_free(ab->name);
  if (ab->path)
    g_free(ab->path);

  /* if notebook has got 2 or more pages, then delete notebook's page number "page" */
  if (pages > 1)    
    {
      gtk_notebook_remove_page(GTK_NOTEBOOK(notebook), page);
      nodo = g_list_nth(book, page);
      book = g_list_remove_link(book, nodo);
      g_list_free_1(nodo);
      rubrica_pages_dec();    
    }
  /* notebook has got only one page (page number 0) */
  else
    {
      cards = ab->clist;
      gtk_clist_clear(GTK_CLIST(cards));           /* clear cards clist   */
      rubrica_init_addressbook_item(ab);           /* init data structure */
      gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(notebook), ab->child, _("no name"));  
      rubrica_apply_addressbook(0);    /* copy data to globals variables */
      rubrica_file_set_start(TRUE);    /* first notebook page */
    }
}


void rubrica_init_addressbook_view(void)
{
  GtkCList *dati;
  
  /* pulisco la clist dati  */
  dati = rubrica_vista_get_dati(); 
  gtk_clist_clear(GTK_CLIST(dati));    
}

