/*
*  Rubrica
*  file: prefer.h
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_PREF_H
#define _RUBRICA_PREF_H

#include "dictionary.h"

typedef struct _RubricaPreferences {
  gboolean show_path;              /* false,  show only filename
				      true  , show path and filename */
  gboolean default_addressbook;    /* true, rubrica must load the setted addressbook 
				      at start 
				      false, rubrica begin with clean screen */
  gboolean alpha;                  /* show cards in alphabetic order */
  gboolean date;                   /* show cards by creation date */
  gboolean increasing;             /* true, show cards fron minor to major */  
  gboolean confirm;                /* true, confirn exit */ 
  gboolean backup;                 /* true, make backup */
  gboolean zip;                    /* true, zip address book */

  gboolean user_dict;              /* true, load user dictionary */
  gboolean use_english;            /* default language are it or en 
				      false - use italian
				      true  - use english */
  gboolean trans_loaded;           /* user's dictionary has been loaded */

  LANG langcode;                   /* code language */
  gchar *language;                 /* language used */
  gchar *short_language;           /* string code language */

  gchar *conf_filename;            /* conf filename */

  gchar *path;                     /* addressbook path (user defined) */
  gchar *addressbook_name;         /* addressbook name (user defined) */

  gchar *user_dictionary;          /* user's dictionary name */
} RubricaPreferences;


void rubrica_preferences_init(gchar *dir, gchar *conf);
gint rubrica_preferences_load();
gboolean rubrica_load_pref(gchar *file);
void rubrica_pref_set_def_file_check(gboolean state);
gboolean rubrica_pref_get_def_file_check(void);
void rubrica_preferences_save(gchar *filename);
void rubrica_save_preferences(void);
RubricaPreferences *rubrica_get_preferences();

/*      functions that manages pref structure
	set boolean values
*/
void rubrica_pref_set_show_path(gboolean show_file);
void rubrica_pref_set_default_addressbook(gboolean default_ab);
void rubrica_pref_set_alpha_order(gboolean ord);
void rubrica_pref_set_date_order(gboolean ord);
void rubrica_pref_set_increasing(gboolean inc);
void rubrica_pref_set_exit_confirm(gboolean confirm);
void rubrica_pref_set_do_backup(gboolean bk);
void rubrica_pref_set_zip_addressbook(gboolean zip);
void rubrica_pref_set_user_dictionary(gboolean use);
void rubrica_pref_set_use_english(gboolean use_eng);

/*      set language values
*/
void rubrica_pref_set_lang_code(LANG code);
void rubrica_pref_set_language(gchar*);
void rubrica_pref_set_short_language(gchar*);

/*      set path/filenames values
*/
void rubrica_pref_set_path(gchar *path);
void rubrica_pref_set_addressbook_fname(gchar *name);
void rubrica_pref_set_dictionary_fname(gchar *name);

/*      get boolean values
*/
gboolean rubrica_pref_get_show_path(void);
gboolean rubrica_pref_get_default_addressbook(void);
gboolean rubrica_pref_get_alpha_order(void);
gboolean rubrica_pref_get_date_order(void);
gboolean rubrica_pref_get_increasing(void);
gboolean rubrica_pref_get_exit_confirm(void);
gboolean rubrica_pref_get_do_backup(void);
gboolean rubrica_pref_get_zip_addressbook(void);
gboolean rubrica_pref_get_use_user_dictionary(void);
gboolean rubrica_pref_get_use_english(void);

LANG rubrica_pref_get_lang_code(void);
gchar* rubrica_pref_get_language(void);
gchar* rubrica_pref_get_short_language(void);

gchar *rubrica_pref_get_path(void);
gchar *rubrica_pref_get_addressbook_fname(void);
gchar *rubrica_pref_get_dictionary_fname(void);

gboolean preferences_loaded(void);
#define preferences_get_pref_load() preferences_loaded(void);


gboolean rubrica_dictionary_is_loaded();
void rubrica_perf_set_load_pref(gboolean load);

void rubrica_pref_apply();
void rubrica_set_prefbox(GtkWidget *w1, GtkWidget *w2, gboolean flag);
void rubrica_pref_button_toggled(GtkToggleButton *togglebutton, gpointer user_data);
void rubrica_refresh_files(gchar *data);
void rubrica_preferences_set(GtkWidget *prop, RubricaPreferences *p);

void rubrica_pref_lang_changed(gboolean state);
void rubrica_pref_lang_code_changed(gboolean state);
gboolean rubrica_pref_lang_is_changed();
gboolean rubrica_pref_lang_code_is_changed();


#endif






