/*
*  Rubrica
*  file: prefer_cb.c
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "prefer.h"
#include "prefer_cb.h"
#include "prefer_int.h"
#include "support.h"
#include "view.h"
#include "dictionary.h"

/*
  Apply button (OK button) was clicked.
  Apply and save user preferences.  
*/

void
on_propertybox_apply                  (GnomePropertyBox *propertybox,
				       gint             arg1,
				       gpointer         user_data)
{
  GtkWidget *label_fn, *entry_ul, *entry_ulc;
  gboolean user_dict;
  RubricaPreferences *p = rubrica_get_preferences();

  user_dict = p->user_dict;

  if (user_dict)
    {
      gchar *ul, *ulc;
      gchar *fn = NULL;

      entry_ul  = gtk_object_get_data(GTK_OBJECT(propertybox), "entry_user_lang");
      entry_ulc = gtk_object_get_data(GTK_OBJECT(propertybox), "entry_user_lang_code");
      label_fn = gtk_object_get_data(GTK_OBJECT(propertybox), "name_dictionary_label");
      
      /* get the string for user dictionary name 
       */
      ul =  g_strdup(gtk_entry_get_text(GTK_ENTRY(entry_ul)));
      rubrica_pref_set_language(ul);

      /* get the string for user dictionary code name 
       */
      ulc =  g_strdup(gtk_entry_get_text(GTK_ENTRY(entry_ulc)));
      rubrica_pref_set_short_language(ulc);
      rubrica_pref_set_lang_code(OTHER);
      
      /* set label for dictionary filename
       */
      fn = g_strdup_printf("%s.dict", ul);
      gtk_label_set_text(GTK_LABEL(label_fn), fn);
      rubrica_pref_set_dictionary_fname(fn);
      
      g_free(ul);
      g_free(ulc);
      g_free(fn);
    }

  if (rubrica_pref_get_show_path())
    {
      rubrica_vista_set_str_label_path(rubrica_pref_get_path());
      rubrica_vista_set_str_label_file(rubrica_pref_get_addressbook_fname());
    }
  else
    {
      rubrica_vista_set_str_label_path(rubrica_pref_get_addressbook_fname());
      rubrica_vista_set_str_label_file(rubrica_pref_get_addressbook_fname());      
    }

  if (rubrica_pref_get_def_file_check())
    {
      GtkWidget *entry_file;
      gchar *tmp;

      entry_file = gtk_object_get_data(GTK_OBJECT(propertybox), "entry_filename");
      tmp = gtk_editable_get_chars(GTK_EDITABLE(entry_file), 0, -1);
      rubrica_refresh_files(tmp);
      g_free(tmp);
    }
  
  if (rubrica_pref_get_use_english())
    {
      rubrica_pref_set_language("English");
      rubrica_pref_set_short_language("En");
    }
  else
    {
      rubrica_pref_set_language("Italian");
      rubrica_pref_set_short_language("It");
    }

  rubrica_save_preferences();
}


/* show_path
   false,  show only filename
   true  , show path and filename 
*/       
void
on_radio_file_toggled             (GtkToggleButton *togglebutton,
				   gpointer         user_data)
{
  rubrica_pref_set_show_path(FALSE);  
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


void
on_radio_path_toggled             (GtkToggleButton *togglebutton,
				   gpointer         user_data)
{
  rubrica_pref_set_show_path(TRUE);  
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));  
}



 /* default_addressbook
    true, rubrica must load the setted addressbook 
    at start false, rubrica begin with clean screen 
 */
void
on_check_default_toggled                (GtkToggleButton *togglebutton,
					 gpointer         user_data)
{
  /*    user_data is a pointer to property box    
	when toggle button is clicked, the widget bring up his state,
	then callback is called. The callback call rubrica_pref_button_toggled
	and when this funtion return property box state is changed.
   */
  rubrica_pref_button_toggled(togglebutton, user_data);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* alpha
   show cards in alphabetic order 
*/
void
on_radio_alfa_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_alpha_order(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* date
   show cards by creation date 
*/
void
on_radio_data_toggled                (GtkToggleButton *togglebutton,
                                      gpointer         user_data)
{
  rubrica_pref_set_date_order(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* increasing
   true, show cards fron minor to major 
   false show cards from major to minor
*/  
void
on_radio_increase_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_increasing(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


void
on_radio_decrease_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_increasing(FALSE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* backup
   true, make always backup 
   false, make never backup
*/
void
on_radio_backup_never_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_do_backup(FALSE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


void
on_radio_backup_always_toggled         (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_do_backup(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* confirm
   true, confirn exit from rubrica
   false don't confirm exit from rubrica
*/ 
void
on_radio_confirm_no_toggled            (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_exit_confirm(FALSE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}

void
on_radio_confirm_yes_toggled           (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
  rubrica_pref_set_exit_confirm(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* zip
   true, zip addressbook 
   false not zip addressbook
*/
void
on_radio_zip_yes_toggled           (GtkToggleButton *togglebutton,
				    gpointer         user_data)
{
  rubrica_pref_set_zip_addressbook(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}

void
on_radio_zip_no_toggled           (GtkToggleButton *togglebutton,
				   gpointer         user_data)
{
  rubrica_pref_set_zip_addressbook(FALSE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* use_italian
   default language are italian and english
   false - use italian as default
   true  - use english as default
*/
void 
on_radio_def_ita_toggled           (GtkToggleButton *togglebutton,
				    gpointer         user_data)
{
  rubrica_pref_set_use_english(FALSE);
  rubrica_pref_set_lang_code(ITALIAN);
  rubrica_pref_set_language("Italian");
  rubrica_pref_set_short_language("It");
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}

void 
on_radio_def_eng_toggled           (GtkToggleButton *togglebutton,
				    gpointer         user_data)
{
  rubrica_pref_set_use_english(TRUE);
  rubrica_pref_set_lang_code(ENGLISH);
  rubrica_pref_set_language("English");
  rubrica_pref_set_short_language("En");
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/* user_dict   
   true, use a user defined dictionary 
   false use one of the default dictionary
*/
void 
on_radio_use_default_dictionary_toggled (GtkToggleButton *togglebutton,
					 gpointer         user_data)
{
  GtkWidget *ewid1, *ewid2, *ldbut, *svbut, *lab;

  ewid1 =  gtk_object_get_data(GTK_OBJECT(user_data), "entry_user_lang");
  ewid2 =  gtk_object_get_data(GTK_OBJECT(user_data), "entry_user_lang_code");
  ldbut =  gtk_object_get_data(GTK_OBJECT(user_data), "load_bt");
  svbut =  gtk_object_get_data(GTK_OBJECT(user_data), "save_bt");
  lab   =  gtk_object_get_data(GTK_OBJECT(user_data), "name_dictionary_label");

  gtk_widget_set_sensitive(GTK_WIDGET(ewid1), FALSE);
  gtk_widget_set_sensitive(GTK_WIDGET(ewid2), FALSE);
  gtk_widget_set_sensitive(GTK_WIDGET(ldbut), FALSE);
  gtk_widget_set_sensitive(GTK_WIDGET(svbut), FALSE);
  gtk_widget_set_sensitive(GTK_WIDGET(lab), FALSE);

  rubrica_pref_set_user_dictionary(FALSE);
  
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));  
}

void
on_radio_use_user_dictionary_toggled    (GtkToggleButton *togglebutton,
					 gpointer         user_data)
{
  GtkWidget *ewid1, *ewid2, *ldbut, *svbut, *lab;

  ewid1 =  gtk_object_get_data(GTK_OBJECT(user_data), "entry_user_lang");
  ewid2 =  gtk_object_get_data(GTK_OBJECT(user_data), "entry_user_lang_code");
  ldbut =  gtk_object_get_data(GTK_OBJECT(user_data), "load_bt");
  svbut =  gtk_object_get_data(GTK_OBJECT(user_data), "save_bt");
  lab   =  gtk_object_get_data(GTK_OBJECT(user_data), "name_dictionary_label");

  gtk_widget_set_sensitive(GTK_WIDGET(ewid1), TRUE);
  gtk_widget_set_sensitive(GTK_WIDGET(ewid2), TRUE);
  gtk_widget_set_sensitive(GTK_WIDGET(ldbut), TRUE);
  gtk_widget_set_sensitive(GTK_WIDGET(svbut), TRUE);
  gtk_widget_set_sensitive(GTK_WIDGET(lab), TRUE);
  
  rubrica_pref_set_user_dictionary(TRUE);
  
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));    
}


/*   entry for addressbook's name that user wants to load at startup 
*/
void
on_entry_filename_changed             (GtkEditable     *editable,
				       gpointer         user_data)
{
  rubrica_pref_set_def_file_check(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));    
}


/*  entry for the language name of user dictionary
*/
void
on_entry_user_lang_changed             (GtkEditable     *editable,
                                        gpointer         user_data)
{
  rubrica_pref_lang_changed(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));    
}


/*  set the code of language that user had choosed
*/
void
on_entry_user_lang_code_changed        (GtkEditable     *editable,
                                        gpointer         user_data)
{
  rubrica_pref_lang_code_changed(TRUE);
  gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}


/*  this callback is called when 
    one entry has changed.
 */
void
on_entry_changed               (GtkEditable     *editable,
				gpointer         user_data)
{
    gnome_property_box_changed(GNOME_PROPERTY_BOX(user_data));
}

/* extract dictionary from notebook and save it 
 */
void
on_but_save_clicked                    (GtkButton       *button,
                                        gpointer         user_data)
{
  Dictionary dict;
  GtkWidget *lang_entry, *shlang_entry;  
  gchar *lang, *shlang;
  LANG l;

  lang_entry = gtk_object_get_data(GTK_OBJECT(user_data),  "entry_user_lang");
  shlang_entry =gtk_object_get_data(GTK_OBJECT(user_data), "entry_user_lang_code");
  
  rubrica_extract_user_dictionary(&dict, user_data);
  rubrica_store_dictionary(dict);
  lang = gtk_entry_get_text(GTK_ENTRY(lang_entry)) ;
  shlang = gtk_entry_get_text(GTK_ENTRY(shlang_entry));
  
  if (strcmp(shlang, "IT") == 0)
    l = ITALIAN;
  if (strcmp(shlang, "EN") == 0) 
    l = ENGLISH;
  else 
    l = OTHER; 
      
  rubrica_save_user_dictionary(dict, l, lang, shlang);
}

void
on_but_load_clicked             (GtkButton       *button,
				 gpointer         user_data)
{
  GtkWidget *lang_entry;  
  gchar *lang, *shlang;

  lang_entry = gtk_object_get_data(GTK_OBJECT(user_data), "entry_user_lang");
  lang = gtk_entry_get_text(GTK_ENTRY(lang_entry)) ;

  rubrica_load_user_dictionary(lang, &shlang);
  rubrica_display_user_dictionary(user_data);      
}


void
on_optionmenu2_clicked             (GtkButton       *button,
				    gpointer         user_data)
{
  /* TO DO */
}
